@@ -16,12 +16,7 @@ extension MAS {
 			abstract: "Sign out of the Apple Account currently signed in to the Mac App Store"
 		)
 
-		/// Runs the command.
-		func run() throws {
-			try mas.run { run(printer: $0) }
-		}
-
-		func run(printer _: Printer) {
+		func run() {
 			ISServiceProxy.genericShared().accountService.signOut()
 		}
 	}
