@@ -7,12 +7,8 @@
 
 internal import Foundation
 
-enum MASError: Error, Equatable {
-	case cancelled
-	case jsonParsing(data: Data)
-	case noDownloads
-	case noSearchResultsFound(for: String)
-	case noVendorWebsite(forAppID: AppID)
+enum MASError: Error {
+	case noCatalogAppsFound(for: String)
 	case notSupported
 	case runtimeError(String)
 	case unknownAppID(AppID)
@@ -22,20 +18,8 @@ enum MASError: Error, Equatable {
 extension MASError: CustomStringConvertible {
 	var description: String {
 		switch self {
-		case .cancelled:
-			"Download cancelled"
-		case let .jsonParsing(data):
-			if let unparsable = String(data: data, encoding: .utf8) {
-				"Unable to parse response as JSON:\n\(unparsable)"
-			} else {
-				"Unable to parse response as JSON"
-			}
-		case .noDownloads:
-			"No downloads began"
-		case let .noSearchResultsFound(searchTerm):
+		case let .noCatalogAppsFound(searchTerm):
 			"No apps found in the Mac App Store for search term: \(searchTerm)"
-		case let .noVendorWebsite(appID):
-			"No vendor website available for app ID \(appID)"
 		case .notSupported:
 			"""
 			This command is not supported on this macOS version due to changes in macOS
@@ -44,7 +28,7 @@ extension MASError: CustomStringConvertible {
 		case let .runtimeError(message):
 			message
 		case let .unknownAppID(appID):
-			"No apps found in the Mac App Store for app ID \(appID)"
+			"No apps found in the Mac App Store for \(appID)"
 		case let .urlParsing(string):
 			"Unable to parse URL from \(string)"
 		}
